componentIndex: Return the index of a gas component by name

View source: R/component_names.R

componentIndexR Documentation

Return the index of a gas component by name

Description

Return the index of a gas component by name

Usage

componentIndex(name)

Arguments

name

Character string: component name (English). See componentNames for the full list.

Value

Integer index (1–60) into the composition vector.


ISO6976.2016 documentation built on April 9, 2026, 5:09 p.m.