componentName: Return the name of a gas component by index

View source: R/component_names.R

componentNameR Documentation

Return the name of a gas component by index

Description

Return the name of a gas component by index

Usage

componentName(index)

Arguments

index

Integer 1–60.

Value

Character string with the English component name.


ISO6976.2016 documentation built on April 9, 2026, 5:09 p.m.